"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TaskRuntime = void 0;
const fs_1 = require("fs");
const path_1 = require("path");
const logging_1 = require("./logging");
const task_1 = require("./task");
// Based on task runtime in Projen
// https://github.com/projen/projen/blob/main/src/task-runtime.ts
class TaskRuntime {
    constructor(workdir, configdir) {
        this.workdir = (0, path_1.resolve)(workdir);
        const manifestPath = (0, path_1.join)(this.workdir, configdir, 'tasks.json');
        this.manifestFileExists = (0, fs_1.existsSync)(manifestPath);
        this.manifest = (0, fs_1.existsSync)(manifestPath)
            ? JSON.parse((0, fs_1.readFileSync)(manifestPath, 'utf-8'))
            : { tasks: {} };
    }
    /**
     * The tasks in this project.
     */
    get tasks() {
        var _a;
        return Object.values((_a = this.manifest.tasks) !== null && _a !== void 0 ? _a : {});
    }
    /**
     * Find a task by name, or `undefined` if not found.
     */
    tryFindTask(name) {
        if (!this.manifest.tasks) {
            return undefined;
        }
        return this.manifest.tasks[name];
    }
    /**
     * Runs the task.
     * @param name The task name.
     */
    runTask(name, parents = []) {
        if (!this.manifestFileExists) {
            (0, logging_1.error)(`Task manifest not found - make sure you are in an application folder`);
            process.exit(1);
        }
        const task = this.tryFindTask(name);
        if (!task) {
            (0, logging_1.error)(`Task '${name}' not found - double check task name`);
            process.exit(1);
        }
        new task_1.Task(this, task, parents);
    }
}
exports.TaskRuntime = TaskRuntime;
